@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -13,22 +13,15 @@
 import os
 import os.path as op
 
+import pytest
 
-from datalad.distribution.dataset import (
-    Dataset
-)
 from datalad.api import create
-from datalad.support.exceptions import CommandError
+from datalad.cmd import WitlessRunner as Runner
+from datalad.distribution.dataset import Dataset
 from datalad.support.annexrepo import AnnexRepo
-from datalad.utils import (
-    chpwd,
-    Path,
-)
-from datalad.cmd import (
-    WitlessRunner as Runner,
-)
-
-from datalad.tests.utils import (
+from datalad.support.exceptions import CommandError
+from datalad.tests.utils_pytest import (
+    OBSCURE_FILENAME,
     assert_in,
     assert_in_results,
     assert_not_in,
@@ -37,13 +30,16 @@ from datalad.tests.utils import (
     assert_status,
     eq_,
     has_symlink_capability,
-    OBSCURE_FILENAME,
     ok_,
     ok_exists,
     swallow_outputs,
     with_tempfile,
     with_tree,
 )
+from datalad.utils import (
+    Path,
+    chpwd,
+)
 
 _dataset_hierarchy_template = {
     'origin': {
@@ -60,7 +56,7 @@ raw = dict(return_type='list', result_filter=None, result_xfm=None, on_failure='
 
 @with_tempfile(mkdir=True)
 @with_tempfile
-def test_create_raises(path, outside_path):
+def test_create_raises(path=None, outside_path=None):
     ds = Dataset(path)
     # incompatible arguments (annex only):
     assert_raises(ValueError, ds.create, annex=False, description='some')
@@ -95,8 +91,8 @@ def test_create_raises(path, outside_path):
 
     # now deinstall the sub and fail trying to create a new one at the
     # same location
-    ds.uninstall(obscure_ds, check=False)
-    assert_in(obscure_ds, ds.subdatasets(fulfilled=False, result_xfm='relpaths'))
+    ds.drop(obscure_ds, what='all', reckless='kill', recursive=True)
+    assert_in(obscure_ds, ds.subdatasets(state='absent', result_xfm='relpaths'))
     # and now should fail to also create inplace or under
     assert_in_results(
         ds.create(obscure_ds, **raw),
@@ -126,7 +122,7 @@ def test_create_raises(path, outside_path):
 
 
 @with_tempfile
-def test_create_force_subds(path):
+def test_create_force_subds(path=None):
     ds = Dataset(path).create()
     subds = ds.create("subds")
     # We get an error when trying calling create in an existing subdataset
@@ -138,7 +134,7 @@ def test_create_force_subds(path):
         subds.create(force=True, **raw),
         status="ok")
     # ... even if it is uninstalled.
-    subds.uninstall()
+    subds.drop(what='all', reckless='kill', recursive=True)
     ok_(not subds.is_installed())
     assert_in_results(
         subds.create(force=True, **raw),
@@ -147,7 +143,7 @@ def test_create_force_subds(path):
 
 @with_tempfile
 @with_tempfile
-def test_create_curdir(path, path2):
+def test_create_curdir(path=None, path2=None):
     with chpwd(path, mkdir=True):
         create()
     ds = Dataset(path)
@@ -164,7 +160,7 @@ def test_create_curdir(path, path2):
 
 @with_tempfile
 @with_tempfile
-def test_create(probe, path):
+def test_create(probe=None, path=None):
     # only as a probe whether this FS is a crippled one
     ar = AnnexRepo(probe, create=True)
 
@@ -192,7 +188,7 @@ def test_create(probe, path):
 
 
 @with_tempfile
-def test_create_sub(path):
+def test_create_sub(path=None):
 
     ds = Dataset(path)
     ds.create()
@@ -237,7 +233,7 @@ def test_create_sub(path):
 
 
 @with_tempfile
-def test_create_sub_gh3463(path):
+def test_create_sub_gh3463(path=None):
     ds = Dataset(path)
     ds.create()
 
@@ -252,14 +248,14 @@ def test_create_sub_gh3463(path):
 
 
 @with_tempfile(mkdir=True)
-def test_create_dataset_same_as_path(path):
+def test_create_dataset_same_as_path(path=None):
     with chpwd(path):
         ds = create(dataset=".", path=".")
     assert_repo_status(ds.path)
 
 
 @with_tempfile
-def test_create_sub_dataset_dot_no_path(path):
+def test_create_sub_dataset_dot_no_path(path=None):
     ds = Dataset(path)
     ds.create()
 
@@ -279,7 +275,7 @@ def test_create_sub_dataset_dot_no_path(path):
 
 
 @with_tree(tree=_dataset_hierarchy_template)
-def test_create_subdataset_hierarchy_from_top(path):
+def test_create_subdataset_hierarchy_from_top(path=None):
     # how it would look like to overlay a subdataset hierarchy onto
     # an existing directory tree
     ds = Dataset(op.join(path, 'origin')).create(force=True)
@@ -310,7 +306,7 @@ def test_create_subdataset_hierarchy_from_top(path):
 
 
 @with_tempfile
-def test_nested_create(path):
+def test_nested_create(path=None):
     # to document some more organic usage pattern
     ds = Dataset(path).create()
     assert_repo_status(ds.path)
@@ -365,7 +361,7 @@ def test_nested_create(path):
 
 # Imported from #1016
 @with_tree({'ds2': {'file1.txt': 'some'}})
-def test_saving_prior(topdir):
+def test_saving_prior(topdir=None):
     # the problem is that we might be saving what is actually needed to be
     # "created"
 
@@ -384,7 +380,7 @@ def test_saving_prior(topdir):
 
 
 @with_tempfile(mkdir=True)
-def test_create_withcfg(path):
+def test_create_withcfg(path=None):
     ds = create(
         dataset=path,
         cfg_proc=['yoda'])
@@ -399,7 +395,7 @@ def test_create_withcfg(path):
 
 
 @with_tempfile(mkdir=True)
-def test_create_fake_dates(path):
+def test_create_fake_dates(path=None):
     ds = create(path, fake_dates=True)
 
     ok_(ds.config.getbool("datalad", "fake-dates"))
@@ -415,7 +411,7 @@ def test_create_fake_dates(path):
 
 
 @with_tempfile(mkdir=True)
-def test_cfg_passthrough(path):
+def test_cfg_passthrough(path=None):
     runner = Runner()
     _ = runner.run(
         ['datalad',
@@ -431,7 +427,7 @@ def test_cfg_passthrough(path):
             "nonempty": {".git": {"bogus": "content"}, "ds": {}},
             "git_with_head": {".git": {"HEAD": ""}, "ds": {}}
             })
-def test_empty_git_upstairs(topdir):
+def test_empty_git_upstairs(topdir=None):
     # create() doesn't get confused by an empty .git/ upstairs (gh-3473)
     assert_in_results(
         create(op.join(topdir, "empty", "ds"), **raw),
@@ -454,10 +450,9 @@ def check_create_obscure(create_kwargs, path):
     ok_(ds.is_installed())
 
 
-def test_create_with_obscure_name():
-    fname = OBSCURE_FILENAME
-    yield check_create_obscure, {"path": fname}
-    yield check_create_obscure, {"dataset": fname}
+@pytest.mark.parametrize("kwarg", ["path", "dataset"])
+def test_create_with_obscure_name(kwarg):
+    check_create_obscure, {"kwarg": OBSCURE_FILENAME}
 
 
 @with_tempfile
@@ -484,24 +479,30 @@ def check_create_path_semantics(
         eq_(subds.pathobj, target_path)
 
 
-def test_create_relpath_semantics():
-    yield check_create_path_semantics, 'subdir', None, 'subdir_relpath'
-    yield check_create_path_semantics, 'subdir', 'abspath', 'subdir_relpath'
-    yield check_create_path_semantics, 'subdir', 'abspath', 'abspath'
-    yield check_create_path_semantics, 'parentds', None, 'relpath'
-    yield check_create_path_semantics, 'parentds', 'abspath', 'relpath'
-    yield check_create_path_semantics, 'parentds', 'abspath', 'abspath'
-    yield check_create_path_semantics, None, 'abspath', 'abspath'
-    yield check_create_path_semantics, None, 'instance', 'abspath'
-    yield check_create_path_semantics, None, 'instance', 'relpath'
-    yield check_create_path_semantics, 'elsewhere', 'abspath', 'abspath'
-    yield check_create_path_semantics, 'elsewhere', 'instance', 'abspath'
-    yield check_create_path_semantics, 'elsewhere', 'instance', 'relpath'
+@pytest.mark.parametrize(
+    "cwd,create_ds,path_arg",
+    [
+        ('subdir', None, 'subdir_relpath'),
+        ('subdir', 'abspath', 'subdir_relpath'),
+        ('subdir', 'abspath', 'abspath'),
+        ('parentds', None, 'relpath'),
+        ('parentds', 'abspath', 'relpath'),
+        ('parentds', 'abspath', 'abspath'),
+        (None, 'abspath', 'abspath'),
+        (None, 'instance', 'abspath'),
+        (None, 'instance', 'relpath'),
+        ('elsewhere', 'abspath', 'abspath'),
+        ('elsewhere', 'instance', 'abspath'),
+        ('elsewhere', 'instance', 'relpath'),
+    ]
+)
+def test_create_relpath_semantics(cwd, create_ds, path_arg):
+    check_create_path_semantics(cwd, create_ds, path_arg)
 
 
 @with_tempfile(mkdir=True)
 @with_tempfile()
-def test_gh2927(path, linkpath):
+def test_gh2927(path=None, linkpath=None):
     if has_symlink_capability():
         # make it more complicated by default
         Path(linkpath).symlink_to(path, target_is_directory=True)
@@ -513,7 +514,7 @@ def test_gh2927(path, linkpath):
 
 
 @with_tempfile(mkdir=True)
-def check_create_initopts_form(form, path):
+def check_create_initopts_form(form, path=None):
     path = Path(path)
 
     template_dir = path / "templates"
@@ -528,6 +529,15 @@ def check_create_initopts_form(form, path):
     ok_exists(ds.repo.dot_git / "foo")
 
 
-def test_create_initopts_form():
-    yield check_create_initopts_form, "dict"
-    yield check_create_initopts_form, "list"
+@pytest.mark.parametrize("form", ["dict", "list"])
+def test_create_initopts_form(form):
+    check_create_initopts_form(form)
+
+
+@with_tempfile
+def test_bad_cfg_proc(path=None):
+    ds = Dataset(path)
+    # check if error is raised for incorrect cfg_proc
+    assert_raises(ValueError, ds.create, path=path, cfg_proc='unknown')
+    # verify that no directory got created prior to the error
+    assert not op.isdir(path)
