@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -11,7 +11,7 @@
 import os
 
 from datalad.distribution.dataset import Dataset
-from datalad.tests.utils import (
+from datalad.tests.utils_pytest import (
     assert_in,
     eq_,
     integration,
@@ -30,7 +30,7 @@ from datalad.tests.utils import (
 @slow  # ~7s
 @integration
 @with_tempfile(mkdir=True)
-def test_download_docker_blob(path):
+def test_download_docker_blob(path=None):
     from datalad.consts import (
         DATALAD_SPECIAL_REMOTE,
         DATALAD_SPECIAL_REMOTES_UUIDS,
