@@ -433,7 +433,7 @@ _definitions = {
     'datalad.log.level': {
         'ui': ('question', {
             'title': 'Used for control the verbosity of logs printed to '
-                     'stdout while running datalad commands/debugging'}),
+                     'stderr while running datalad commands/debugging'}),
     },
     'datalad.log.result-level': {
         'ui': ('question', {
@@ -545,7 +545,7 @@ _definitions = {
                'title': 'git-annex repository version',
                'text': 'Specifies the repository version for git-annex to be used by default'}),
         'type': EnsureInt(),
-        'default': 8,
+        'default': 10,
     },
     'datalad.runtime.max-annex-jobs': {
         'ui': ('question', {
