@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-; coding: utf-8 -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -16,8 +16,7 @@ import os.path as op
 from itertools import product
 from unittest.mock import patch
 
-from ..globbedpaths import GlobbedPaths
-from datalad.tests.utils import (
+from datalad.tests.utils_pytest import (
     OBSCURE_FILENAME,
     assert_in,
     eq_,
@@ -25,6 +24,8 @@ from datalad.tests.utils import (
     with_tree,
 )
 
+from ..globbedpaths import GlobbedPaths
+
 
 def test_globbedpaths_get_sub_patterns():
     gp = GlobbedPaths([], "doesn't matter")
@@ -58,8 +59,8 @@ bOBSCURE_FILENAME = f"b{OBSCURE_FILENAME}.dat"
                  "2.dat": "",
                  "3.txt": "",
                  bOBSCURE_FILENAME: "",
-                 "subdir": {"1.txt": "", "2.txt": ""}})
-def test_globbedpaths(path):
+                 "subdir": {"1.txt": "", "2.txt": "", "subsub": {"3.dat": ""}}})
+def test_globbedpaths(path=None):
     dotdir = op.curdir + op.sep
 
     for patterns, expected in [
@@ -74,7 +75,15 @@ def test_globbedpaths(path):
             ([dotdir + op.join("subdir", "*.txt")],
              {dotdir + op.join(*ps)
               for ps in [("subdir", "1.txt"), ("subdir", "2.txt")]}),
-            (["*.txt"], {"1.txt", "3.txt"})]:
+            (["*.txt"], {"1.txt", "3.txt"}),
+            ([op.join("subdir", "**")],
+             {op.join(*ps)
+              for ps in [("subdir" + op.sep,), ("subdir", "subsub"),
+                         ("subdir", "1.txt"), ("subdir", "2.txt"),
+                         ("subdir", "subsub", "3.dat")]}),
+            ([dotdir + op.join("**", "*.dat")],
+             {dotdir + op.join("2.dat"), dotdir + bOBSCURE_FILENAME,
+              dotdir + op.join("subdir", "subsub", "3.dat")})]:
         gp = GlobbedPaths(patterns, pwd=path)
         eq_(set(gp.expand()), expected)
         eq_(set(gp.expand(full=True)),
@@ -110,7 +119,7 @@ def test_globbedpaths(path):
     # We can the glob outputs.
     glob_results = {"z": "z",
                     "a": ["x", "d", "b"]}
-    with patch('glob.glob', glob_results.get):
+    with patch('glob.glob', lambda k, **kwargs: glob_results[k]):
         gp = GlobbedPaths(["z", "a"])
         eq_(gp.expand(), ["z", "b", "d", "x"])
 
@@ -126,7 +135,7 @@ def test_globbedpaths(path):
 
 
 @with_tree(tree={"1.txt": "", "2.dat": "", "3.txt": ""})
-def test_globbedpaths_misses(path):
+def test_globbedpaths_misses(path=None):
     gp = GlobbedPaths(["amiss"], pwd=path)
     eq_(gp.expand_strict(), [])
     eq_(gp.misses, ["amiss"])
@@ -170,7 +179,7 @@ def test_globbedpaths_misses(path):
                  "bdir": {},
                  "other": {},
                  "1.txt": "", "2.dat": "", "3.txt": ""})
-def test_globbedpaths_partial_matches(path):
+def test_globbedpaths_partial_matches(path=None):
     gp = GlobbedPaths([op.join("?dir", "*.txt"), "*.txt"], pwd=path)
     eq_(gp.expand_strict(), ["1.txt", "3.txt"])
 
@@ -188,7 +197,7 @@ def test_globbedpaths_partial_matches(path):
                  "2.dat": "",
                  "3.txt": "",
                  "foo.dat": ""})
-def test_globbedpaths_cached(path):
+def test_globbedpaths_cached(path=None):
     # Smoke test to trigger cache handling.
     gp = GlobbedPaths([op.join("?", ".dat"), "*.txt"], pwd=path)
     for full, partial, misses in product([False, True], repeat=3):
