@@ -1,4 +1,4 @@
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -9,4 +9,4 @@
 """
 
 from datalad.support.external_versions import external_versions
-from datalad.tests.utils import *
+from datalad.tests.utils_pytest import *
