@@ -21,6 +21,7 @@ from http.server import (
     SimpleHTTPRequestHandler,
 )
 from json import dumps
+from typing import Optional
 from unittest import SkipTest
 from unittest.mock import patch
 
@@ -36,8 +37,8 @@ from datalad.cmd import (
 from datalad.consts import ARCHIVES_TEMP_DIR
 from datalad.dochelpers import borrowkwargs
 from datalad.support.external_versions import (
+    LooseVersion,
     external_versions,
-    get_rsync_version,
 )
 from datalad.support.keyring_ import MemoryKeyring
 from datalad.support.network import RI
@@ -1117,25 +1118,6 @@ def with_sameas_remote(func, autoenabled=False):
     @with_tempfile(mkdir=True)
     @with_tempfile(mkdir=True)
     def  _wrap_with_sameas_remote(*args, **kwargs):
-        # With git-annex's 8.20200522-77-g1f2e2d15e, transferring from an rsync
-        # special remote hangs on Xenial. This is likely due to an interaction
-        # with an older rsync or openssh version. Use openssh as a rough
-        # indicator. See
-        # https://git-annex.branchable.com/bugs/Recent_hang_with_rsync_remote_with_older_systems___40__Xenial__44___Jessie__41__/
-        if external_versions['cmd:system-ssh'] < '7.4' and \
-           '8.20200522' < external_versions['cmd:annex'] < '8.20200720':
-            pytest.skip("Test known to hang")
-
-        # A fix in rsync 3.2.4 broke compatibility with older annex versions.
-        # To make things a bit more complicated, ubuntu pulled that fix into
-        # their rsync package for 3.1.3-8.
-        # Issue: gh-7320
-        rsync_ver = get_rsync_version()
-        rsync_fixed = rsync_ver >= "3.1.3-8ubuntu" or rsync_ver >= "3.2.4"
-        if rsync_fixed and external_versions['cmd:annex'] < "10.20220504":
-            pytest.skip(f"rsync {rsync_ver} and git-annex "
-                        f"{external_versions['cmd:annex']} incompatible")
-
         sr_path, repo_path = args[-2:]
         fn_args = args[:-2]
         repo = AnnexRepo(repo_path)
@@ -2023,7 +2005,7 @@ def set_date(timestamp):
 
 
 @contextmanager
-def set_annex_version(version):
+def set_annex_version(version: Optional[str]):
     """Override the git-annex version.
 
     This temporarily masks the git-annex version present in external_versions
@@ -2033,7 +2015,7 @@ def set_annex_version(version):
     ar_vers = AnnexRepo.git_annex_version
     with patch.dict(
             "datalad.support.annexrepo.external_versions._versions",
-            {"cmd:annex": version}):
+            {"cmd:annex": LooseVersion(version) if version else version}):
         try:
             AnnexRepo.git_annex_version = None
             yield
